==> cms-db_v0.5.1.tar.gz: admin/firstrun4.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('firstrun');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>cms -db Installationsassistent</title>
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1>Installationsassistent - Schritt 4</h1>
<h2>Abschlie&szlig;en der Installation</h2>
<?php
include("../data/settings/url.inc.php");
$urlabsolute = ereg_replace("/admin/firstrun4.php?(.*)",'', $_SERVER["REQUEST_URI"]);
$writethis = '<?php
$urlbefore = "'.$urlbefore.'";
$urlafter = "'.$urlafter.'";
$urlabsolute = "'.$urlabsolute.'";
?>';
$datei = fopen('../data/settings/url.inc.php','w+');
fwrite($datei,$writethis);
fclose($datei);
copy('./update/version.txt', '../data/version.txt');
?>
<p>
	Die Einrichtung von <span style="font-family: FreeMono,Courier,monospace">cms&nbsp;</span><span style="color: #ff0000; font-family: FreeMono,Courier,monospace">-db</span> wurde abgeschlossen. Sie k&ouml;nnen sich nun anmelden und mit der Anpassung des Templates und der Einstellungen beginnen sowie Seiten erstellen und bearbeiten.
</p>
<p>
	<a href="logout.php?<?php echo SID ?>">zur Anmeldung</a>
</p>

</body>
</html>

==> cms-db_v0.7.9.tar.gz: admin/firstrun4.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('firstrun');
include('locale.inc.php');
$locale = new LocalizingClass('firstrun');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_step4') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_step4') ?></h1>
<h2><?php locale('title_finished') ?></h2>
<?php
include("../data/settings/url.inc.php");
$urlabsolute = ereg_replace("/admin/firstrun4.php?(.*)",'', $_SERVER["REQUEST_URI"]);
$writethis = '<?php
$urlbefore = "'.$urlbefore.'";
$urlafter = "'.$urlafter.'";
$urlabsolute = "'.$urlabsolute.'";
?>';
$datei = fopen('../data/settings/url.inc.php','w+');
fwrite($datei,$writethis);
fclose($datei);
file_put_contents('../data/settings/locale.inc.php', '<?php
$locale_default = "'.$_SESSION['CMS-Locale'].'";
?>');
copy('./update/version.txt', '../data/version.txt');
?>
<p>
	<?php locale('desc_finished') ?>
</p>
<p>
	<a href="logout.php?<?php echo SID ?>"><?php locale('link_login') ?></a>
</p>

</body>
</html>
